==> base-domain-RD1002931-20200721.075642-5-sources.jar: com/thebeastshop/scm/vo/recommend/OrderFinishRecommendParamVO.java <==
package com.thebeastshop.scm.vo.recommend;

import java.math.BigDecimal;
import java.util.List;

import pers.richard.ormybatis.domain.core.AbstractDomain;

/**
 * 订单完成自动推荐调用接口传参VO 
 * @author donghui
 */
public class OrderFinishRecommendParamVO extends AbstractDomain {
	private List<String> productCodes;//多个商品code
	private Integer limitSize;//记录数
	private String chnCode;//渠道
	private Integer memberLevel;
	private Integer accessWay;
	private BigDecimal discount;//会员折扣
	private BigDecimal bdDiscount;//生日折扣

	private String userId;
	private String imei;
	private String ip;
	private String sceneId;
	
	public OrderFinishRecommendParamVO(){}
	
	public List<String> getProductCodes() {
		return productCodes;
	}

	public void setProductCodes(List<String> productCodes) {
		this.productCodes = productCodes;
	}
	public String getChnCode() {
		return chnCode;
	}

	public void setChnCode(String chnCode) {
		this.chnCode = chnCode;
	}
	public Integer getLimitSize() {
		return limitSize;
	}

	public void setLimitSize(Integer limitSize) {
		this.limitSize = limitSize;
	}

	public Integer getMemberLevel() {
		return memberLevel;
	}

	public void setMemberLevel(Integer memberLevel) {
		this.memberLevel = memberLevel;
	}

	public Integer getAccessWay() {
		return accessWay;
	}

	public void setAccessWay(Integer accessWay) {
		this.accessWay = accessWay;
	}

	public BigDecimal getDiscount() {
		return discount;
	}

	public void setDiscount(BigDecimal discount) {
		this.discount = discount;
	}
	public BigDecimal getBdDiscount() {
		return bdDiscount;
	}

	public void setBdDiscount(BigDecimal bdDiscount) {
		this.bdDiscount = bdDiscount;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}

	public String getImei() {
		return imei;
	}

	public void setImei(String imei) {
		this.imei = imei;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public String getSceneId() {
		return sceneId;
	}

	public void setSceneId(String sceneId) {
		this.sceneId = sceneId;
	}
}

==> base-domain-RD1004374-20211202.024329-2-sources.jar: com/thebeastshop/scm/vo/recommend/OrderFinishRecommendParamVO.java <==
package com.thebeastshop.scm.vo.recommend;

import java.math.BigDecimal;
import java.util.List;

import com.thebeastshop.scm.es.RecommendSceneTypeEnum;
import pers.richard.ormybatis.domain.core.AbstractDomain;

/**
 * 订单完成自动推荐调用接口传参VO 
 * @author donghui
 */
public class OrderFinishRecommendParamVO extends AbstractDomain {
	private List<String> productCodes;//多个商品code
	private Integer limitSize;//记录数
	private String chnCode;//渠道
	private Integer memberLevel;
	private Integer accessWay;
	private BigDecimal discount;//会员折扣
	private BigDecimal bdDiscount;//生日折扣

	private String memberCode;
	private String imei;
	private String ip;
	private RecommendSceneTypeEnum recommendSceneTypeEnum;
	
	public OrderFinishRecommendParamVO(){}
	
	public List<String> getProductCodes() {
		return productCodes;
	}

	public void setProductCodes(List<String> productCodes) {
		this.productCodes = productCodes;
	}
	public String getChnCode() {
		return chnCode;
	}

	public void setChnCode(String chnCode) {
		this.chnCode = chnCode;
	}
	public Integer getLimitSize() {
		return limitSize;
	}

	public void setLimitSize(Integer limitSize) {
		this.limitSize = limitSize;
	}

	public Integer getMemberLevel() {
		return memberLevel;
	}

	public void setMemberLevel(Integer memberLevel) {
		this.memberLevel = memberLevel;
	}

	public Integer getAccessWay() {
		return accessWay;
	}

	public void setAccessWay(Integer accessWay) {
		this.accessWay = accessWay;
	}

	public BigDecimal getDiscount() {
		return discount;
	}

	public void setDiscount(BigDecimal discount) {
		this.discount = discount;
	}
	public BigDecimal getBdDiscount() {
		return bdDiscount;
	}

	public void setBdDiscount(BigDecimal bdDiscount) {
		this.bdDiscount = bdDiscount;
	}

	public String getMemberCode() {
		return memberCode;
	}

	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode;
	}

	public String getImei() {
		return imei;
	}

	public void setImei(String imei) {
		this.imei = imei;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public RecommendSceneTypeEnum getRecommendSceneTypeEnum() {
		return recommendSceneTypeEnum;
	}

	public void setRecommendSceneTypeEnum(RecommendSceneTypeEnum recommendSceneTypeEnum) {
		this.recommendSceneTypeEnum = recommendSceneTypeEnum;
	}
}
